@@ -276,6 +276,11 @@ def decode_limits(attributes: Dict):
     else:
         return CardLimitsDTO.from_json_api(attributes)
 
+def mapping_wraper(_id, _type, attributes, relationships):
+    if _type in mappings:
+        return mappings[_type](_id, _type, attributes, relationships)
+    else:
+        return RawUnitObject(_id, _type, attributes, relationships)
 
 class DtoDecoder(object):
     @staticmethod
@@ -287,12 +292,12 @@ class DtoDecoder(object):
             dtos = split_json_api_array_response(payload)
             response = []
             for _id, _type, attributes, relationships in dtos:
-                response.append(mappings[_type](_id, _type, attributes, relationships))
+                response.append(mapping_wraper(_id, _type, attributes, relationships))
 
             return response
         else:
             _id, _type, attributes, relationships = split_json_api_single_response(payload)
-            return mappings[_type](_id, _type, attributes, relationships)
+            return mapping_wraper(_id, _type, attributes, relationships)
 
 class UnitEncoder(json.JSONEncoder):
     def default(self, obj):
